==> javie-0.3.4-src.tar.gz: javie-0.3.4-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/internal/services/VideoRenderContextProxy.java <==
/*
 * Copyright (c) 2009 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.internal.services;

import javax.media.opengl.GL;
import javax.media.opengl.glu.GLU;

import ch.kuramo.javie.api.ColorMode;
import ch.kuramo.javie.api.RenderResolution;
import ch.kuramo.javie.core.services.VideoRenderContext;

public class VideoRenderContextProxy
		extends AbstractRenderContextProxy<VideoRenderContextImpl>
		implements VideoRenderContext {

	private static final ThreadLocal<VideoRenderContextImpl>
			_threadLocal = new ThreadLocal<VideoRenderContextImpl>();

	protected ThreadLocal<VideoRenderContextImpl> getThreadLocal() {
		return _threadLocal;
	}

	public GL getGL() {
		return getImpl().getGL();
	}

	public GLU getGLU() {
		return getImpl().getGLU();
	}

	public RenderResolution getRenderResolution() {
		return getImpl().getRenderResolution();
	}

	public void setRenderResolution(RenderResolution resolution) {
		getImpl().setRenderResolution(resolution);
	}

	public ColorMode getColorMode() {
		return getImpl().getColorMode();
	}

	public void setColorMode(ColorMode colorMode) {
		getImpl().setColorMode(colorMode);
	}

}

==> javie-0.3.10-src.tar.gz: javie-0.3.10-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/internal/services/VideoRenderContextProxy.java <==
/*
 * Copyright (c) 2009,2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core.internal.services;

import javax.media.opengl.GL;
import javax.media.opengl.glu.GLU;

import ch.kuramo.javie.api.ColorMode;
import ch.kuramo.javie.api.RenderResolution;
import ch.kuramo.javie.api.Time;
import ch.kuramo.javie.core.services.VideoRenderContext;

public class VideoRenderContextProxy
		extends AbstractRenderContextProxy<VideoRenderContextImpl>
		implements VideoRenderContext {

	private static final ThreadLocal<VideoRenderContextImpl>
			_threadLocal = new ThreadLocal<VideoRenderContextImpl>();

	protected ThreadLocal<VideoRenderContextImpl> getThreadLocal() {
		return _threadLocal;
	}

	public GL getGL() {
		return getImpl().getGL();
	}

	public GLU getGLU() {
		return getImpl().getGLU();
	}

	public RenderResolution getRenderResolution() {
		return getImpl().getRenderResolution();
	}

	public void setRenderResolution(RenderResolution resolution) {
		getImpl().setRenderResolution(resolution);
	}

	public ColorMode getColorMode() {
		return getImpl().getColorMode();
	}

	public void setColorMode(ColorMode colorMode) {
		getImpl().setColorMode(colorMode);
	}

	public Time getFrameDuration() {
		return getImpl().getFrameDuration();
	}

	public void setFrameDuration(Time frameDuration) {
		getImpl().setFrameDuration(frameDuration);
	}

}
